(harmonic_ref)=

# ktch.harmonic

```{eval-rst}
.. automodule:: ktch.harmonic
   :no-members:
   :no-inherited-members:
```

## Classes

```{eval-rst}
.. currentmodule:: ktch

.. autosummary::
   :toctree: generated/
   :template: base.rst

   harmonic.EllipticFourierAnalysis
   harmonic.SphericalHarmonicAnalysis
```

## Functions

```{eval-rst}
.. currentmodule:: ktch

.. autosummary::
   :toctree: generated/
   :template: base.rst
   
   harmonic.spharm
   harmonic.xyz2spherical
```
